#
# spec file for package trilead-ssh2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global buildver 217
%global patchlvl 293
%global githash  v56de4d4d3515

Name:           trilead-ssh2
Version:        %{buildver}.%{patchlvl}.%{githash}
Release:        1.4
Summary:        SSH-2 protocol implementation in pure Java
License:        BSD-3-Clause AND MIT
Group:          Development/Libraries/Java
URL:            https://github.com/jenkinsci/trilead-ssh2
Source0:        https://github.com/jenkinsci/%{name}/archive/refs/tags/build-%{buildver}-jenkins-%{patchlvl}.%{githash}.tar.gz
Source1:        %{name}-build.xml
Patch0:         0001-Remove-the-dependency-on-google-tink.patch
BuildRequires:  ant
BuildRequires:  ed25519-java
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  jbcrypt
BuildArch:      noarch

%description
Trilead SSH-2 for Java is a library which implements the SSH-2 protocol in pure
Java (tested on J2SE 1.4.2 and 5.0). It allows one to connect to SSH servers
from within Java programs. It supports SSH sessions (remote command execution
and shell access), local and remote port forwarding, local stream forwarding,
X11 forwarding and SCP. There are no dependencies on any JCE provider, as all
crypto functionality is included.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-build-%{buildver}-jenkins-%{patchlvl}.%{githash}
%patch -P 0 -p1
cp %{SOURCE1} build.xml

%pom_remove_dep :tink
%pom_xpath_set pom:project/pom:version "build-%{buildver}-jenkins-%{patchlvl}.%{githash}"

%build
mkdir -p lib
build-jar-repository -s lib eddsa jbcrypt
%{ant} package javadoc

%install
# jars
install -d -m 0755 %{buildroot}%{_javadir}
install -m 644 target/%{name}-*.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar -a "org.tmatesoft.svnkit:trilead-ssh2","com.trilead:trilead-ssh2"

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -aL target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt
%doc HISTORY.txt README.txt

%files javadoc
%license LICENSE.txt
%{_javadocdir}/%{name}

%changelog
* Thu Mar 14 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to version build-217-jenkins-293.v56de4d4d3515
  * Trilead ssh2 fix big integer removes leading zero
    Addresses CVE-2023-48795, bsc#1218198
  * JENKINS-72466 - : Upgrades jbcrypt dependency
- Includes changes from previous version updates:
  * JENKINS-71798 - : TimeoutService threads are left after closing
    connection
  * Giving threads names for easier troubleshooting
  * Update parent POM
  * There is no guarantee that the plugin works with Java 8 anymore,
    and it is not tested. If you still run Jenkins  on Java 8 do not
    update. JENKINS-69229
  * Removal of unnecessary protobuf-java
  * fix: bump protobuff due to CVE 2021 22569
  * JENKINS-69018 - use constant MAX_PACKET_SIZE
  * add support for hmac-sha2-512-etm@openssh.com
    hmac-sha2-256-etm@opensh.com in trilead-ssh2
  * feat: enable continuous delivery workflow
  * additional kex algorithms
  * [Revert]JENKINS-62552 - Use standard crypto APIs
  * feat: enable incrementals
  * Retry userauth when multiple algs
  * Known Issue: JENKINS-63790 causes SSH agent connections to fail
    in some configurations
  * fix: allow to use password encrypted keys
  * Known Issue: trilead api 1.0.9 fails clone from ssh repository
    using 3DES/MD5-encrypted private key JENKINS-63601
  * JENKINS-62552 - Use standard crypto APIs
  * Resolve several possible infinite hangings because of wait()
  * Revert "JENKINS-62311 - Add support for RFC 8332"
  * [SECURITY] Use HTTPS to resolve dependencies in Maven Build
  * JENKINS-62311 - Add support for RFC 8332
  * Support for port=0 which means automatically allocated port.
  * JENKINS-59857 - Kerberos support updated
- Added patch:
  * 0001-Remove-the-dependency-on-google-tink.patch
    + remove new code dependent on google tink since we don't have
    the dependency
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Tue Apr 16 2019 Fridrich Strba <fstrba@suse.com>
- Fix the license tag and clean up the spec file a bit
* Wed Oct 24 2018 Fridrich Strba <fstrba@suse.com>
- Initial packaging built manually without maven. Spec file adapted
  from Fedora rpm.
